from django import template

register = template.Library()


@register.filter
def separate_by_slash(value):
    if not value:
        return value

    value = value.replace("(", "")
    value = value.replace(")", " /")
    return value



import logging
import mimetypes
import os
import re
from base64 import b64encode

from django.conf import settings
from django.contrib.staticfiles import finders
from django.core.files.base import File, ContentFile
from django.core.mail.message import EmailMultiAlternatives, EmailMessage
from django.db.models.fields.files import FieldFile
from django.template import engines, loader

from rh_email_tpl.utils.translation import custom_translation_override

logger = logging.getLogger(__name__)


class RHEmailMessage:
    subject = ""
    template_html = ""
    template_text = ""
    generate_text_from_html = False
    email_multi_alternatives_class = EmailMultiAlternatives
    reply_to = []
    sender_display_label = None

    def __init__(
        self,
        subject="",
        template_html="",
        template_text="",
        generate_text_from_html=False,
        context=None,
        from_email=None,
        to=None,
        cc=None,
        bcc=None,
        reply_to=None,
        attached_files=None,
        extra_email_kwargs=None,
        sender_display_label=None,
        *args,
        **kwargs,
    ):
        if args:
            logger.warning("Received unsupported args: %s", args, extra={"args": args})
        if kwargs:
            logger.warning(
                "Received unsupported kwargs: %s", kwargs, extra={"kwargs": kwargs}
            )

        self.subject = self.subject or subject
        self.template_html = template_html or self.template_html
        self.template_text = template_text or self.template_text
        self.generate_text_from_html = (
            self.generate_text_from_html or generate_text_from_html
        )
        self.context = context
        self.from_email = from_email
        self.to = to
        self.cc = cc
        self.bcc = bcc
        self.reply_to = reply_to
        self.attached_files = attached_files
        self.extra_email_kwargs = extra_email_kwargs
        self.sender_display_label = sender_display_label

    def get_context_data(self):
        return self.context or {}

    def get_from_email(self):
        if not self.from_email:
            raise NotImplementedError
        return self.from_email

    def get_to(self):
        if not self.to:
            raise NotImplementedError
        return self.to

    def get_cc(self):
        return self.cc or []

    def get_bcc(self):
        return self.bcc or []

    def get_reply_to(self):
        return self.reply_to or []

    def get_attached_files(self):
        return self.attached_files or []

    def get_subject(self):
        return self.subject

    def get_sender_display_label(self):
        return self.sender_display_label

    def get_final_from_email(self):
        sender_display_label = self.get_sender_display_label()
        from_email = self.get_from_email()
        if sender_display_label:
            return f"{sender_display_label} <{from_email}>"
        return from_email

    def get_template_html(self):
        return self.template_html

    def get_template_text(self):
        return self.template_text

    def get_generate_text_from_html(self):
        return self.generate_text_from_html

    def get_body_html(self, replace_cid_urls=False):
        html = loader.get_template(self.get_template_html()).render(
            self.get_context_data()
        )

        if replace_cid_urls:
            html = html.replace("cid:", "")

        return html

    def get_body_text(self):
        context = self.get_context_data()
        if self.get_generate_text_from_html():
            context["__text_output__"] = True
            html_template = loader.get_template(self.get_template_html()).template
            template = engines["django"].from_string(
                html_template.source.replace(".html", ".txt")
            )
            del context[
                "__text_output__"
            ]  # unset the flag afterwards to avoid strange side-effects
        else:
            template = loader.get_template(self.get_template_text())

        text = template.render(context)
        return self.clean_up_body_text(text)

    def clean_up_body_text(self, text):
        text = text.replace("\r", "")

        # replace double spaces by single one
        while "  " in text:
            text = text.replace("  ", " ")

        # remove lines with only one space
        while "\n \n" in text:
            text = text.replace("\n \n", "\n\n")

        # replace multiple empty lines by single one
        while "\n\n\n" in text:
            text = text.replace("\n\n\n", "\n\n")

        text = re.sub(r"__LINEBREAK__", "\n", text)
        text = re.sub(r"<br.*?>", "\n", text)
        text = re.sub(r"<.*?>", "", text)
        text = text.replace("\n", "\r\n")
        return text.strip()

    def get_image_path(self, image_file):
        # handle /media/ urls
        if image_file.startswith(settings.MEDIA_URL):
            directory, filename = os.path.split(image_file)
            directory = os.path.join(
                settings.MEDIA_ROOT, directory[len(settings.MEDIA_URL) :]  # noqa: E203
            )
        # all other images taken from static root
        else:
            directory, filename = os.path.split(image_file)
            result = finders.find("/".join(directory.split("/")[2:]))
            if result:
                if isinstance(result, list):
                    result = result[0]
                directory = result
            else:
                logger.warning("Was unable to find static file %s", image_file)
        return os.path.join(directory, filename)

    def _process_html_body(self, msg):
        body_html = self.get_body_html()
        image_files = set(re.findall(r'cid:([^"\']+)', body_html))
        for image_file in image_files:
            b64_image_file = b64encode(image_file.encode("utf-8")).decode("utf-8")
            # add image and replace cid with base64 alias
            msg.attach_inline_image(
                filepath=self.get_image_path(image_file), cid=b64_image_file
            )
            body_html = body_html.replace(
                "cid:%s" % image_file, "cid:%s" % b64_image_file
            )
        msg.attach_alternative(body_html, "text/html")

    def get_extra_email_kwargs(self):
        """
        Pass extra kwargs to email_multi_alternatives_class initialisation
        """
        return self.extra_email_kwargs or {}

    def pre_send(self):
        """
        Called before sending email, if validation is needed as an example
        """
        return

    @custom_translation_override("de")
    def send_email(self):
        self.pre_send()

        msg = self.email_multi_alternatives_class(
            subject=self.get_subject(),
            body=self.get_body_text(),
            from_email=self.get_final_from_email(),
            to=self._clean_address_list(self.get_to()),
            cc=self._clean_address_list(self.get_cc()),
            bcc=self._clean_address_list(self.get_bcc()),
            reply_to=self._clean_address_list(self.get_reply_to()),
            **self.get_extra_email_kwargs(),
        )
        self._process_html_body(msg)
        self.add_attachments(msg)

        msg.send()

    def add_attachments(self, email_message):
        for _file in self.get_attached_files():
            if isinstance(_file, str):
                with open(_file, "rb") as f:
                    self.add_attachment(f, email_message)
            else:
                self.add_attachment(_file, email_message)

    def add_attachment(self, _file: File, email_message: EmailMessage):
        content_type, encoding = mimetypes.guess_type(_file.name)
        email_message.attach(os.path.basename(_file.name), _file.read(), content_type)

    def add_attachment_by_filename(
        self, email_message: EmailMessage, filename: str, description: str
    ):
        try:
            with open(filename, "rb") as attachment_file:
                attachment = File(file=attachment_file, name=description)
                self.add_attachment(attachment, email_message)
        except IOError:
            if settings.DEBUG:
                logger.error("file not found to attach: %s", filename)
            else:
                raise

    def add_attachment_by_content(
        self, email_message: EmailMessage, content: str, description: str
    ):
        attachment = ContentFile(content=content, name=description)
        self.add_attachment(attachment, email_message)

    def add_attachment_by_fieldfile(self, email_message, fieldfile, description=None):
        assert isinstance(fieldfile, FieldFile)
        if description is None:
            description = fieldfile.name
        self.add_attachment_by_filename(
            email_message=email_message,
            filename=fieldfile.path,
            description=description,
        )

    def send(self):
        return self.send_email()

    def _clean_address_list(self, _list):
        if not isinstance(_list, (list, tuple, set)):
            raise ValueError("addresses must be provided as list, tuple or set")
        return _list and [e for e in set(_list) if e]



from functools import wraps

from django.utils import translation


def custom_translation_override(language):
    """
    Custom decorator which re-implements translation.override in a recursion-safe way.
    :param language: language-code string
    :return: function wrapped with translation.override context manager
    """

    def wrapper(func):
        @wraps(func)
        def inner(*args, **kwargs):
            with translation.override(language):
                return func(*args, **kwargs)

        return inner

    return wrapper



import os

import django
from django.conf import settings
from django.template import Context
from django.template.loader import get_template
from django.test import TestCase
from django.test.utils import override_settings
from lxml import html
from lxml.sax import etree

# based on https://github.com/alexhayes/django-premailer/blob/master/django_premailer/templatetags/premailer.py
# which is not maintained anymore

TESTS_TEMPLATE_DIR = os.path.join(
    os.path.dirname(os.path.abspath(__file__)), "premailer_templates"
)

TEMPLATES = settings.TEMPLATES
TEMPLATES[0]["DIRS"].append(TESTS_TEMPLATE_DIR)


@override_settings(TEMPLATES=TEMPLATES)
class PremailerTests(TestCase):
    def pretty(self, ugly):
        """
        Force a HTML document to be made pretty.
        NOTE: This method is required because of strange differences in the way premailer/lxml makes decisions about
        the placement of newlines. Using tox all tests pass without this hack, however in travis and circleci the
        :py:meth:`.PremailerTests.test_basic` test fails due to some missing ``\n`` in the generated ``actual`` HTML.
        """
        document_root = html.fromstring(
            ugly.replace("\n", "").replace("\t", "").replace("  ", "")
        )
        return etree.tostring(document_root, encoding="unicode", pretty_print=True)

    def assert_expected(self, actual, expected):
        with open(os.path.join(TESTS_TEMPLATE_DIR, expected), "r") as f:
            expected = f.read()
            self.assertEqual(self.pretty(actual), self.pretty(expected))

    def test_basic(self):
        """
        A very basic test that ensures the tag does what we expect it to do.
        """
        template = get_template("basic.html")
        context = Context({"eggs": "Sausage"})
        if django.VERSION >= (1, 8):
            context = context.flatten()
        rendered = template.render(context)
        self.assert_expected(rendered, "basic.expected.html")

    def test_basic_base_url(self):
        """
        Override the base_url.
        """
        template = get_template("basic-base-url.html")
        context = Context({"eggs": "Sausage"})
        if django.VERSION >= (1, 8):
            context = context.flatten()
        rendered = template.render(context)
        self.assert_expected(rendered, "basic-base-url.expected.html")



import sys

from django import template
from django.conf import settings
from premailer import Premailer

# based on https://github.com/alexhayes/django-premailer/blob/master/django_premailer/templatetags/premailer.py
# which is not maintained anymore

register = template.Library()

PREMAILER_OPTIONS = getattr(settings, "PREMAILER_OPTIONS", {})


class PremailerNode(template.Node):
    def __init__(self, nodelist, filter_expressions):
        self.nodelist = nodelist
        self.filter_expressions = filter_expressions

    def render(self, context):
        rendered_contents = self.nodelist.render(context)
        kwargs = {
            "include_star_selectors": True,
            "cssutils_logging_level": "CRITICAL",
        }

        if "test" in sys.argv:
            kwargs["base_url"] = "http://example.com"

        for expression in self.filter_expressions:
            kwargs.update(base_url=expression.resolve(context, True))

        transformed = Premailer(rendered_contents, **kwargs).transform()
        return transformed


@register.tag
def premailer(parser, token):
    nodelist = parser.parse(("endpremailer",))

    # prevent second parsing of endpremailer
    parser.delete_first_token()

    args = token.split_contents()[1:]

    return PremailerNode(nodelist, [parser.compile_filter(arg) for arg in args])



import logging

from django import template as dj_template
from django.template import loader
from django.template.base import FilterExpression, Variable
from django.template.defaulttags import token_kwargs

logger = logging.getLogger(__name__)
register = dj_template.Library()


def generate_block_tag(parser, token, tag_class, endtag, **kwargs):
    """Factory for creating tags."""
    bits = token.split_contents()
    extra_context = token_kwargs(bits[1:], parser)
    nodelist = parser.parse((endtag,))
    parser.delete_first_token()
    return tag_class(nodelist, extra_context, **kwargs)


class EmailBlockTag(dj_template.Node):
    """
    Node for rendering a meta element which doesn't have it's own text
    representation but uses the one from the contained elements.

    Acts as a block and assigns the content of the block to the value of
    ``CONTEXT_VAR_CONTENT`` in the context of the underlying template.

    Additional context variables can be added that will be used when rendering
    the _underlying template_, this will influence the context of the block!

    For example, given a underlying template of::

        <p class='{{ color }}'>{{ text }}</p>

    And the main context has template variable color='blue', the following::

        {% emailparagraph color='red' %}
            The car is {{ color }}.
        {% endemailparagraph %}

    Will render as::

        <p class='red'>The car is blue.</p>
    """

    # This is what the content of the block will be referred to as in the
    # underlying template.
    CONTEXT_VAR_CONTENT = "text"

    def __init__(self, nodelist, extra_context, template_html=None):
        self.extra_context = extra_context
        self.template_html = template_html
        self.nodelist = nodelist

    def render(self, context):
        template = self.get_template(context)
        content = self.nodelist.render(context)
        values = self.parse_context(context, content)

        with context.push(values):
            output = template.render(context.flatten())

        return output

    def get_template(self, context):
        return loader.get_template(self.template_html)

    def _resolve_var(self, var, context):
        """
        Workaround for some variables being already resolved.
        """
        if not isinstance(var, (FilterExpression, Variable)):
            return var
        return var.resolve(context)

    def parse_context(self, context, content=None):
        content = content or ""
        values = {
            key: self._resolve_var(val, context)
            for key, val in self.extra_context.items()
        }
        values[self.CONTEXT_VAR_CONTENT] = self.clean_content(content)
        return values

    def clean_content(self, content):
        """
        Remove all unnecessary whitespace and newlines from content.
        """
        return " ".join(content.split())


class EmailTextHtmlBlockTag(EmailBlockTag):
    """
    Same as EmailBlockTag but will automatically generate a text version using the
    template_text template file.
    """

    TEMPLATE_HTML = None  # required
    TEMPLATE_TEXT = None  # not required

    # This context variable determines if the text or HTML version
    # will be rendered.
    CONTEXT_VAR_TEXT = "__text_output__"

    def __init__(
        self, nodelist, extra_context=None, template_html=None, template_text=None
    ):
        super(EmailTextHtmlBlockTag, self).__init__(
            nodelist=nodelist, extra_context=extra_context, template_html=template_html
        )
        self.template_text = template_text or self.TEMPLATE_TEXT

    def render(self, context):
        template = self.get_template(context)
        content = self.nodelist.render(context)
        values = self.parse_context(context, content)

        with context.push(values):
            output = template.render(context.flatten())

        return output

    def get_template(self, context):
        """
        Get the underlying template to use based on what the CONTEXT_VAR_TEXT
        context variable is set to.

        The TEMPLATE_HTML class constant is required, the TEMPLATE_TEXT class
        constant is optional. If TEMPLATE_TEXT is not set, it is assumed that
        the html file's extension can just be changed from .html to .txt
        """
        if not self.is_txt_version(context):
            template_filename = self.template_html
        elif self.template_text:
            template_filename = self.template_text
        else:
            template_filename = self.template_html.replace(".html", ".txt")
        return loader.get_template(template_filename)

    def is_txt_version(self, context):
        return context.get(self.CONTEXT_VAR_TEXT, False)


class EmailTextHtmlPreserveWhitespaceBlockTag(EmailTextHtmlBlockTag):
    """
    Same as EmailTextHtmlBlockTag, but doesn't remove whitespace from content.
    """

    def clean_content(self, content):
        return content


# base components as building bricks for emails and meta components


@register.tag("emailheader")
def do_email_header(parser, token):
    """
    header of the email containing company logos

    {% emailheader %}{% endemailheader %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailheader",
        template_html="email/som/tags/header.html",
    )


@register.tag("emailfooter")
def do_email_footer(parser, token):
    """
    footer of the email containing imprint and legal information

    {% emailfooter %}{% endemailfooter %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailfooter",
        template_html="email/som/tags/footer.html",
    )


@register.tag("emailcontent")
def do_email_content(parser, token):
    """
    content area with grey background

    {% emailcontent %}
      Some other content, may be text or additional elements
    {% endemailcontent %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlPreserveWhitespaceBlockTag,
        "endemailcontent",
        template_html="email/som/tags/content.html",
    )


@register.tag("emailunsubscribe")
def do_email_unsubscribe(parser, token):
    """
    part of the email containing the unsubscribe possibility

    {% emailunsubscribe %}{% endemailunsubscribe %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailunsubscribe",
        template_html="email/som/tags/unsubscribe.html",
    )


@register.tag("emailparagraph")
def do_email_paragraph(parser, token):
    """
    paragraph with bottom margin

    {% emailparagraph %}
      Some other content, may be text or additional elements
    {% endemailparagraph %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailparagraph",
        template_html="email/som/tags/paragraph.html",
    )


@register.tag("emailsmall")
def do_email_small(parser, token):
    """
    small text

    {% emailsmall %}
      Some small content, may be text or additional elements
    {% endemailsmall %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailsmall",
        template_html="email/som/tags/small.html",
    )


@register.tag("emailmedium")
def do_email_medium(parser, token):
    """
    medium sized text

    {% emailmedium %}
      Some medium sized content, may be text or additional elements
    {% endemailmedium %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailmedium",
        template_html="email/som/tags/medium.html",
    )


@register.tag("emailcenter")
def do_email_center(parser, token):
    """
    centered content

    {% emailcenter %}
      Some centered content, may be text or additional elements
    {% endemailcenter %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailcenter",
        template_html="email/som/tags/center.html",
    )


@register.tag("emailheading")
def do_email_heading(parser, token):
    """
    orange heading

    {% emailheading %}This is my heading text {% endemailheading %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailheading",
        template_html="email/som/tags/heading.html",
    )


@register.tag("emailsectionheadline")
def do_email_section_headline(parser, token):
    """
    section headline

    {% emailsectionheadline %}This is a headline{% endemailsectionheadline %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailsectionheadline",
        template_html="email/som/tags/section_headline.html",
    )


@register.tag("emailsection")
def do_email_section(parser, token):
    """
    section devider (with optional leading image)

    {% emailsection %}This is a section{% endemailsection %}

    Accepted arguments:
        image (optional) - path to the static image file
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailsection",
        template_html="email/som/tags/section.html",
    )


@register.tag("emaileyecatcher")
def do_email_eyecatcher(parser, token):
    """
    orange eye catcher element (with optional leading image and subline)

    {% emaileyecatcher
       image="img/email/som/eyecatcher_impressions.png"
       subline="Awesome subline text" %}
        This is an eyecatcher
    {% endemaileyecatcher %}

    Accepted arguments:
        image (optional) - path to the static image file
        subline (optional) - text shown below the eyecatcher heading
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemaileyecatcher",
        template_html="email/som/tags/eyecatcher.html",
    )


@register.tag("emailserviceemployee")
def do_email_service_employee(parser, token):
    """
    service employee image and contact component

    Accepts arguments:
        service_employee (required) - user instance of the service employee
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailserviceemployee",
        template_html="email/som/tags/service_employee.html",
    )


@register.tag("emailbutton")
def do_email_button(parser, token):
    """
    an action button with a target url and text

    Accepted arguments:
        link (required) - target url to link to
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailbutton",
        template_html="email/som/tags/button.html",
    )


@register.tag("emailstripline")
def do_email_stripline(parser, token):
    """
    horizontal divider line
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailstripline",
        template_html="email/som/tags/stripline.html",
    )


@register.tag("emaillist")
def do_email_list(parser, token):
    """
    list container to render emaillistitem elements

    Accepts arguments:
        ordered (optional, default: False) - define if it should be an ordered
          or unordered list
        padding (optional, default: 0) - element padding
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemaillist",
        template_html="email/som/tags/list.html",
    )


@register.tag("emaillistitem")
def do_email_listitem(parser, token):
    """
    list item

    Accepts arguments:
        bullet_color (optional, default: inherit) - color of the bullet point)
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemaillistitem",
        template_html="email/som/tags/list_item.html",
    )


@register.tag("emailcolor")
def do_email_color(parser, token):
    """
    colored text

    Accepts arguments:
        color (required) - hex code of color with leading hash
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailcolor",
        template_html="email/som/tags/color.html",
    )


@register.tag("emailbold")
def do_email_bold(parser, token):
    """
    bold formatted text
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailbold",
        template_html="email/som/tags/bold.html",
    )


@register.tag("emailitalic")
def do_email_italic(parser, token):
    """
    italic text
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailitalic",
        template_html="email/som/tags/italic.html",
    )


@register.tag("emailwarning")
def do_email_warning(parser, token):
    """
    warning message with leading warning sign image
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailwarning",
        template_html="email/som/tags/warning.html",
    )


@register.tag("emailtable")
def do_email_table(parser, token):
    """
    table base element that should contain extaclty one of emailtable_thead
    and/or emailtable_tbody element
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailtable",
        template_html="email/som/tags/table.html",
    )


@register.tag("emailtable_noborder")
def do_email_table_noborder(parser, token):
    """
    table base element that should contain extaclty one of emailtable_thead
    and/or emailtable_tbody element
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailtable_noborder",
        template_html="email/som/tags/table_noborder.html",
    )


@register.tag("emailtable_thead")
def do_email_table_thead(parser, token):
    """
    table header container that should contain exactly one emailtable_tr element
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailtable_thead",
        template_html="email/som/tags/table_thead.html",
    )


@register.tag("emailtable_tbody")
def do_email_table_tbody(parser, token):
    """
    table body container that should contain one or more emailtable_tr elements
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailtable_tbody",
        template_html="email/som/tags/table_tbody.html",
    )


@register.tag("emailtable_tr")
def do_email_table_tr(parser, token):
    """
    table row container that should contain one or more emailtable_td cell elements
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailtable_tr",
        template_html="email/som/tags/table_tr.html",
    )


@register.tag("emailtable_th")
def do_email_table_th(parser, token):
    """
    a table header cell element
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailtable_th",
        template_html="email/som/tags/table_th.html",
    )


@register.tag("emailtable_td")
def do_email_table_td(parser, token):
    """
    a regular table cell element
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailtable_td",
        template_html="email/som/tags/table_td.html",
    )


@register.tag("emaillinebreak")
def do_email_linebreak(parser, token):
    """
    line break
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemaillinebreak",
        template_html="email/som/tags/line_break.html",
    )


@register.tag("emaillink")
def do_email_link(parser, token):
    """
    link

    Accepts arguments:
        placeholder (optional) - an alternative text version
        protocol (optional) - mailto|tel etc., used to hide these protocols in
          the text variant
        remove_underline
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemaillink",
        template_html="email/som/tags/link.html",
    )


@register.tag("emailnowrap")
def do_email_nowrap(parser, token):
    """
    make content non-wrappable
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailnowrap",
        template_html="email/som/tags/nowrap.html",
    )


@register.tag("emailcode")
def do_email_code(parser, token):
    """
    display code in a proper way
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlPreserveWhitespaceBlockTag,
        "endemailcode",
        template_html="email/som/tags/code.html",
    )


@register.tag("emailpre")
def do_email_pre(parser, token):
    """
    preformatted text
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlPreserveWhitespaceBlockTag,
        "endemailpre",
        template_html="email/som/tags/pre.html",
    )


@register.tag("emaildel")
def do_email_del(parser, token):
    """
    deleted text.

    {% emaildel %}
      Some small content, may be text or additional elements
    {% endemaildel %}
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemaildel",
        template_html="email/som/tags/del.html",
    )


@register.tag("emailhtmlescape")
def do_email_html_escape(parser, token):
    """
    raw html that is properly encoded
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlPreserveWhitespaceBlockTag,
        "endemailhtmlescape",
        template_html="email/som/tags/html_escape.html",
    )


@register.tag("emailcolorpreview")
def do_email_color_preview(parser, token):
    """
    color preview.

    Accepts arguments:
        color (required) - the color to preview
        placeholder (optional) - an alternative text representation
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailcolorpreview",
        template_html="email/som/tags/color_preview.html",
    )


@register.tag("emailspacer")
def do_email_spacer(parser, token):
    """
    add some space between other elements
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailspacer",
        template_html="email/som/tags/spacer.html",
    )


@register.tag("emailimage")
def do_email_image(parser, token):
    """
    Block tag for rendering an image. Block contents are used for image URL.

    Accepts arguments:
        alt_text
        width
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailimage",
        template_html="email/som/tags/image.html",
    )


@register.tag("emailstarrating")
def do_email_star_rating(parser, token):
    """
    Star rating

    Accepts arguments:
        score
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailstarrating",
        template_html="email/som/tags/star_rating.html",
    )


@register.tag("emailstar")
def do_email_star(parser, token):
    """
    Star

    Accepts arguments:
        color
        size_px
    """
    return generate_block_tag(
        parser,
        token,
        EmailTextHtmlBlockTag,
        "endemailstar",
        template_html="email/som/tags/star.html",
    )


# META components built from other components


@register.tag("emailsalutation")
def do_email_salutation(parser, token):
    """
    closing salutation

    Accepts arguments:
        service_employee (optional) - user instance of the service employee,
          will fall back to generic salutation
    """
    return generate_block_tag(
        parser,
        token,
        EmailBlockTag,
        "endemailsalutation",
        template_html="email/som/tags/meta/salutation.html",
    )



import os
import re
from os.path import join, dirname
from setuptools import setup, find_namespace_packages


def get_version(*file_paths):
    """Retrieves the version from the given path"""
    filename = os.path.join(os.path.dirname(__file__), *file_paths)
    with open(filename) as f:
        version_file = f.read()
    version_match = re.search(r"^__version__ = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


def long_description():
    """Return long description from README.md if it's present
    because it doesn't get installed."""
    try:
        with open(join(dirname(__file__), "README.md")) as f:
            return f.read()
    except IOError:
        return ""


setup(
    name="rh_email_tpl",
    packages=find_namespace_packages(exclude=["example*"]),
    version=get_version("rh_email_tpl", "__init__.py"),
    description="Internal RegioHelden tool for building styled html emails",
    author="RegioHelden <entwicklung@regiohelden.de>",
    author_email="entwicklung@regiohelden.de",
    long_description=long_description(),
    long_description_content_type="text/markdown",
    install_requires=[
        "Django>=4.2",
        "premailer>=3.10.0",
    ],
    license="",
    url="",
    download_url="",
    keywords=[],
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: System :: Monitoring",
    ],
)
